import { Component } from '@angular/core';
import { IonicPage, NavController, NavParams, LoadingController } from 'ionic-angular';
import { LocalStorageProvider } from '../../providers/local-storage/local-storage';
import { FCM } from '@ionic-native/fcm';
import { ToastController } from 'ionic-angular';
import { QuedadasApiProvider } from '../../providers/quedadas-api/quedadas-api';
import { Storage } from '@ionic/storage';
import { LaunchNavigator, LaunchNavigatorOptions } from '@ionic-native/launch-navigator';
import { SocialSharing } from '@ionic-native/social-sharing';
import {JwtHelper} from "angular2-jwt";
import { OwnerPipe } from '../../pipes/owner/owner'
import { AttendPipe } from '../../pipes/attend/attend'
import { AlertController } from 'ionic-angular';

@IonicPage()
@Component({
  selector: 'page-dashboard',
  templateUrl: 'dashboard.html',
})
export class DashboardPage {

  quedadas: any[] = [];
  quedadasCopy: any[] [];  
  private KEY_TOKEN = 'token_jwt';
  private jwtToken = null;
  statusQuedada: string;
  attendees: any[] = [];
  segment: string;
  myId: string;
  query: string = '';
  van: any = [];
  novan: any = [];
  pensando: any = [];
  mymessage: string = 'Notificacion recivida';
  usermessage: string = '';

  jwtHelper = new JwtHelper();

  constructor(public navCtrl: NavController, public navParams: NavParams, 
                public fcm: FCM, private localStorageProvider: LocalStorageProvider, private toastCtrl: ToastController, 
                private quedadaApiProvider: QuedadasApiProvider, private storage: Storage, private loadingController: LoadingController
                ,private launchNavigator: LaunchNavigator, private socialSharing: SocialSharing, private alertController: AlertController ) {
                  this.registerNotification();
                  this.segment = 'ownerSegment';
  }

  goToCreateQuedada(){
    this.navCtrl.push('CreateQuedadaPage');
  }

  ionViewDidLoad() {
    this.storage.get(this.KEY_TOKEN)
      .then((value) => {
        this.jwtToken = value;
      
        if(!this.jwtToken){
          
          this.navCtrl.setRoot('LoginPage');
        }
        else{
         this.myId = this.jwtHelper.decodeToken(this.jwtToken)._id;
         this.getQuedadasFromServer();
        }
      })
      .catch(() => {
        this.jwtToken = null;
        this.navCtrl.setRoot('LoginPage');
      });
  }

  ionViewDidEnter(){
    this.getQuedadasFromServer();
  }

  getUserYesGo(quedada){
    this.attendees = quedada.attendees;
      return this.van = this.attendees.filter(attendees => attendees.status === 'Attend').length;
  }

  getUserDoNotAttend(quedada){
    this.attendees = quedada.attendees;
     return   this.novan = this.attendees.filter(attendees => attendees.status == 'DoNotAttend').length;
  }

  getUserMaybeAttend(quedada){
    this.attendees = quedada.attendees;
      return  this.pensando = this.attendees.filter(attendees => attendees.status == 'Maybe').length;
  }

  getQuedadasFromServer(){
    let load = this.loadingController.create({
      content: 'Actualizando datos'
    });
    load.present();
    this.quedadaApiProvider.getQuedadas(this.jwtToken)
      .then((data: any) =>{
        load.dismiss();
        this.quedadas = data.results;
        this.quedadasCopy = this.quedadas;
        console.log(this.quedadas);
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  

  navigateToLocation(location: any){
    let options: LaunchNavigatorOptions = {
      start: location,
      app: this.launchNavigator.APP.GOOGLE_MAPS
    };
    
    this.launchNavigator.navigate(location, options)
      .then(
        success => console.log('Launched navigator'),
        error => console.log('Error launching navigator', error)
      );
  }
//
  shareQuedada(quedada: any){
     this.socialSharing.share(
        quedada.attendees[0].displayName+' te invita a una quedada',
        'Accede a este link para acceder a la quedada: ' +quedada.name,
        null,
         'https://quedadas.ovh/#/'+quedada.id
      ).then(
        () => console.log('Ok share'),
        () => console.log('Fails to share...')
      );


  }

  registerNotification(){
    this.fcm.getToken().then( token =>{
        console.log(token);
       
    });
    this.fcm.onNotification().subscribe(data => {
      console.log("valor de data ",data);
      if(data.wasTapped){
        console.log(data);
        this.goToDetails(data.meetingId);
      } else {
        
        if(data.actionType == "UserJoined"){
          console.log('lo que manda el push', data);
          this.mymessage = "ha realizado una acción sobre la quedada";
          if(data.attendeeStatus == "DoNotAttend"){
            this.mymessage = "No va a la quedada: " + data.meetingName;
          }
          if(data.attendeeStatus == "Attend"){
            this.mymessage = "Si va a la quedada: " + data.meetingName;
          }
          if(data.attendeeStatus == "Maybe"){
            this.mymessage = "Se esta pensando ir a: " + data.meetingName;
          }
          if(data.attendeeStatus == "Undefined"){
            this.mymessage = "ha visto la quedada: " + data.meetingName;
          }
          this.usermessage = data.attendeeDisplayName
        }

        if(data.actionType == "MeetingUpdated"){
           this.mymessage = "La quedada " + data.meetingName + " ha sufrido modificaciones";
           this.usermessage = '';
        }

        let toast = this.toastCtrl.create({
          message: this.usermessage + ' '+ this.mymessage,
          duration: 4000,
          position: 'top'
        });
      
        toast.onDidDismiss(() => {
          console.log('Dismissed toast');
        });
      
        toast.present();
      
      }
     
    });
    
  }

  onInput(){
    this.quedadas = this.quedadasCopy;

    let val = this.query;

    if(val && val.trim() != ''){
      this.quedadas = this.quedadas.filter((quedada) => {
          return(quedada.name.toLowerCase().indexOf(val.toLowerCase()) > -1);
      })
    }
  }

  selectSegemntValue(segment: string){
    this.segment = segment;
  }

  goToDetails(id: string){
    this.navCtrl.push('DetailsPage', {
      id: id
    });
  }

  yesAttendQuedada(id: string){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    this.quedadaApiProvider.attendQuedada(this.jwtToken, id)
      .then((data: any) =>{
        load.dismiss();
        this.getQuedadasFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  noAttendQuedada(id: string){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    this.quedadaApiProvider.doNotAttendQuedada(this.jwtToken, id)
      .then((data: any) =>{
        load.dismiss();
        this.getQuedadasFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  maybeAttendQuedada(id: string){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    this.quedadaApiProvider.maybeAttendQuedada(this.jwtToken, id)
      .then((data: any) =>{
        load.dismiss();
        this.getQuedadasFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  setStatusQuedadColorVoy(quedada: any){
    let myStatusInQuedada = quedada.attendees.find(i => i.id === this.myId).status;
    if(myStatusInQuedada == 'Attend')
    {
      return 'letraAzulLogo';
    }
    else{
      return 'dark';
    }
  }

  setStatusQuedadColorNoVoy(quedada: any){
    let myStatusInQuedada = quedada.attendees.find(i => i.id === this.myId).status;
    if(myStatusInQuedada == 'DoNotAttend')
    {
      return 'letraAzulLogo';
    }
    else{
      return 'dark';
    }
  }

  setStatusQuedadColorMaybe(quedada: any){
    let myStatusInQuedada = quedada.attendees.find(i => i.id === this.myId).status;
    if(myStatusInQuedada == 'Maybe')
    {
      return 'letraAzulLogo';
    }
    else{
      return 'dark';
    }
  }

}
