import { Component } from '@angular/core';
import { IonicPage, NavController, NavParams, LoadingController } from 'ionic-angular';
import { AlertController } from 'ionic-angular';
import { Storage } from '@ionic/storage';
import { SocialSharing } from '@ionic-native/social-sharing';
import { QuedadasApiProvider } from '../../providers/quedadas-api/quedadas-api';
import {JwtHelper} from "angular2-jwt";
import { LaunchNavigator, LaunchNavigatorOptions } from '@ionic-native/launch-navigator';
import { ToastController } from 'ionic-angular';
/**
 * Generated class for the DetailsPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */
@IonicPage()
@Component({
  selector: 'page-details',
  templateUrl: 'details.html',
})
export class DetailsPage {
  RadioOpen: boolean;
  voyNovoyResult;
  voy: string = 'voy';
  iconVoy: string = 'thumbs-up';
  id: string;
  quedada: any = [];
  attendees: any[] = [];
  private KEY_TOKEN = 'token_jwt';
  private jwtToken = null;
  owner: any = [];
  quedadaDate: any;
  van: any = [];
  novan: any = [];
  pensando: any = [];
  jwtHelper = new JwtHelper();
  myId: string;
  imOwner: boolean;
  colorYesStatus: string = "dark";
  colorNoStatus: string = "dark";
  colorMaybeStatus: string = "dark";

  miSegment: string = 'details';
  constructor(public navCtrl: NavController, public navParams: NavParams, public alertCtrl: AlertController
                ,private storage: Storage, private loadingController: LoadingController, private quedadaApiProvider: QuedadasApiProvider,
                private socialSharing: SocialSharing, private launchNavigator: LaunchNavigator, private toastCtrl: ToastController) {
    this.id = navParams.get("id");
    this.colorMaybeStatus = "primary";
  }

  

  ionViewDidLoad() {
   
    this.storage.get(this.KEY_TOKEN)
    .then((value) => {
      this.jwtToken = value;
      if(!this.jwtToken){
        
        this.navCtrl.setRoot('LoginPage');
      }
      else{
       this.getQuedadaFromServer();
      }
    })
    .catch(() => {
      this.jwtToken = null;
      this.navCtrl.push('LoginPage');
    });
  }

  ionViewDidEnter(){
  
    this.storage.get(this.KEY_TOKEN)
    .then((value) => {
      this.jwtToken = value;
      if(!this.jwtToken){
        
        this.navCtrl.setRoot('LoginPage');
      }
      else{
       this.getQuedadaFromServer();
      }
    })
    .catch(() => {
      this.jwtToken = null;
      this.navCtrl.setRoot('LoginPage');
    });
  }

  getQuedadaFromServer(){
    let load = this.loadingController.create({
      content: 'Actualizando datos'
    });
    load.present();
   
    this.quedadaApiProvider.joinQuedada(this.jwtToken, this.id)
      .then((data: any) =>{
        load.dismiss();
        this.quedada = data;
        this.attendees = this.quedada.attendees;
        this.van = this.attendees.filter(attendees => attendees.status === 'Attend');
        this.novan = this.attendees.filter(attendees => attendees.status == 'DoNotAttend');
        this.pensando = this.attendees.filter(attendees => attendees.status == 'Maybe');
      
        this.quedadaDate = new Date(this.quedada.dateTimeUtc).toDateString();
        
        this.owner = this.quedada.attendees.find(i => i.id === this.quedada.createdBy);
        let myStatus = this.quedada.attendees.find(i => i.id === this.jwtHelper.decodeToken(this.jwtToken)._id).status;
        this.myId = this.jwtHelper.decodeToken(this.jwtToken)._id;
        

        if(myStatus == 'Attend')
        {
          this.colorYesStatus = 'letraAzulLogo';
          this.colorNoStatus = 'dark';
          this.colorMaybeStatus = 'dark';

        }
        if(myStatus == 'DoNotAttend')
        {
          this.colorYesStatus = 'dark';
          this.colorNoStatus = 'letraAzulLogo';
          this.colorMaybeStatus = 'dark';
        }
        if(myStatus == 'Maybe')
        {
          this.colorYesStatus = 'dark';
          this.colorNoStatus = 'dark';
          this.colorMaybeStatus = 'letraAzulLogo';
        }
        if(myStatus == 'Undefined')
        {
          this.colorYesStatus = 'dark';
          this.colorNoStatus = 'dark';
          this.colorMaybeStatus = 'dark';
        }
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
        let toast = this.toastCtrl.create({
          message: 'Lo siento, esta quedada ya no está activa.',
          duration: 3000,
          position: 'middle'
        });
      
        toast.onDidDismiss(() => {
          this.navCtrl.pop();
        });
      
        toast.present();
        
      }
      );
  }

  attendQuedadFromServer(){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    this.quedadaApiProvider.attendQuedada(this.jwtToken, this.id)
      .then((data: any) =>{
        load.dismiss();
        this.colorYesStatus = 'letraAzulLogo';
        this.getQuedadaFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  noAttendQuedadFromServer(){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    console.log('el id es ', this.id);
    this.quedadaApiProvider.doNotAttendQuedada(this.jwtToken, this.id)
      .then((data: any) =>{
        load.dismiss();
        this.colorNoStatus = 'letraAzulLogo';
        this.getQuedadaFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  maybeAttendQuedadFromServer(){
    let load = this.loadingController.create({
      content: 'Cambiando estado...'
    });
    load.present();
    console.log('el id es ', this.id);
    this.quedadaApiProvider.maybeAttendQuedada(this.jwtToken, this.id)
      .then((data: any) =>{
        load.dismiss();
        this.colorMaybeStatus = 'letraAzulLogo';
        this.getQuedadaFromServer();
      })
      .catch(error => {
        load.dismiss();
        console.error(error);
      }
      );
  }

  shareQuedada(quedada: any){
    console.log('Sharing....');
     this.socialSharing.share(
        quedada.attendees[0].displayName+' te invita a una quedada',
        'Accede a este link para acceder a la quedada: ' +quedada.name,
        null,
         'https://quedadas.ovh/#/'+quedada.id
      ).then(
        () => console.log('Ok share'),
        () => console.log('Fails to share...')
      );


  }

  navigateToLocation(location: any){
    let options: LaunchNavigatorOptions = {
      start: location,
      app: this.launchNavigator.APP.GOOGLE_MAPS
    };
    
    this.launchNavigator.navigate(location, options)
      .then(
        success => console.log('Launched navigator'),
        error => console.log('Error launching navigator', error)
      );
  }

  goToEditQuedada(quedada){
    
    this.navCtrl.push('CreateQuedadaPage', {
      quedada: quedada
    });
  }

  cancelQuedada(quedada: any){
    let alert = this.alertCtrl.create({
      title: 'Cancelar Quedada',
      message: 'Está seguro que desea cancelar la quedada'+quedada.name,
      buttons: [
        {
          text: 'No',
          role: 'cancel',
          handler: () => {
            console.log('Cancel clicked');
          }
        },
        {
          text: 'Sí, estoy seguro',
          handler: () => {
            let load = this.loadingController.create({
              content: 'Cambiando estado...'
            });
            load.present();
          
            this.quedadaApiProvider.cancelQuedada(this.jwtToken, this.id)
              .then((data: any) =>{
                load.dismiss();
                this.navCtrl.pop();
              })
              .catch(error => {
                load.dismiss();
                console.error(error);
              }
              );
          }
        }
      ]
    });
    alert.present();
 
}
 

}
