import { Component } from '@angular/core';
import { IonicPage, ViewController, NavParams, NavController } from 'ionic-angular';
import {
  GoogleMaps,
  GoogleMap,
  GoogleMapsEvent,
  GoogleMapOptions,
  CameraPosition,
  MarkerOptions,
  Geocoder,
  GeocoderRequest, 
  GeocoderResult,
  Marker,
  LatLng
} from '@ionic-native/google-maps';
import { NativeGeocoder, NativeGeocoderReverseResult, NativeGeocoderForwardResult } from '@ionic-native/native-geocoder';
import { Platform } from 'ionic-angular';
import { GeocoderProvider } from '../../providers/geocoder/geocoder';
import { Geolocation } from '@ionic-native/geolocation';
import { GlobalvarsProvider} from '../../providers/globalvars/globalvars';

@IonicPage()
@Component({
  selector: 'page-map',
  templateUrl: 'map.html',
})
export class MapPage {

  map: GoogleMap;
  public coordinates: NativeGeocoderForwardResult;
  public myPosition: any;
  currentPosition: any = {};
  public direccion: any;
  public address: string;

  

  constructor(public viewCtrl: ViewController, public navParams: NavParams,  private googleMaps: GoogleMaps, public plt: Platform, private nativeGeocoder: NativeGeocoder,
    private geolocation: Geolocation, public navCtrl: NavController, public globalvars: GlobalvarsProvider) {
    this.direccion = navParams.get("direccion");
    
  }

  ionViewDidLoad() {
  
    if(this.direccion)
    {  
      this.nativeGeocoder.forwardGeocode(this.direccion)
          .then((coordinates) => {this.myPosition = new LatLng(parseFloat(coordinates[0].latitude),coordinates[0].longitude)
          , this.setMap()})
          .catch((error: any) => console.log(error));
    }
    else{
  
      this.geolocation.getCurrentPosition().then((resp) => {
  
        this.myPosition =  new LatLng(resp.coords.latitude,resp.coords.longitude);
        this.setMap();
       }).catch((error) => {
  
       });
       
    }

  

  }

  setMap(){
  
    
    this.nativeGeocoder.reverseGeocode(this.myPosition.lat, this.myPosition.lng)
      .then((result: NativeGeocoderReverseResult) => this.direccion = JSON.stringify(result))
      .catch((error: any) => console.log(error));
    
    this.plt.ready().then(()=>{
      this.map = GoogleMaps.create('map_canvas');
      this.map.one(GoogleMapsEvent.MAP_READY).then((data:any)=>{
        
        this.map.animateCamera({target: this.myPosition, zoom: 14 })

        let markerOptions: MarkerOptions = {
        position: this.myPosition,
        icon: './assets/imgs/marker.png',
        draggable: true,
        title: this.direccion
        //[(this.direccion[0].thoroughfare || "") + " " + (this.direccion[0].subThoroughfare || ""),this.direccion[0].locality].join(", ")
      };
      
      this.map.addMarker(markerOptions)

      .then(marker => {
        this.setMArket(marker);
        marker.on(GoogleMapsEvent.MARKER_DRAG_END).subscribe(()=>{
        this.myPosition = marker.getPosition();
        this.setGeocoder(this.myPosition.lat, this.myPosition.lng);
        this.setMArket(marker);
        })
      })
        
   
      })
    }).catch(err => {
      
    })
  }

  setGeocoder(lat, lng){
    this.nativeGeocoder.reverseGeocode(lat, lng)
        .then((result: NativeGeocoderReverseResult) => {this.direccion = JSON.stringify(result)})
        .catch((error: any) => console.log(error));
  }

  setMArket(marker){
    let myJsonStringAddress = JSON.parse(this.direccion);
    this.address = myJsonStringAddress[0].thoroughfare + ", " + myJsonStringAddress[0].postalCode + ". " + myJsonStringAddress[0].locality + ". " + myJsonStringAddress[0].countryName;
    
    marker.setTitle(this.address);
    marker.showInfoWindow();
  }

  dismiss(){
    this.viewCtrl.dismiss(this.address);
  }

  sendMap(){
    
    this.globalvars.setMyGlobalVar(this.address);
    this.globalvars.setLatitudeGlobal(this.myPosition.lat);
    this.globalvars.setLongitudeGlobal(this.myPosition.lng);
    this.navCtrl.pop();
   
  }


  loadMap(){

    let mapOptions: GoogleMapOptions = {
      camera: {
        target: {
          lat: 43.0741904, // default location
          lng: -89.3809802 // default location
        },
        zoom: 18,
        tilt: 30
      }
    };
    
    this.map = GoogleMaps.create('map_canvas', mapOptions);
    

    // Wait the MAP_READY before using any methods.
    this.map.one(GoogleMapsEvent.MAP_READY)
    .then(() => {
      this.map.addMarker({
        title: 'Ionic',
        icon: 'blue',
        animation: 'DROP',
        position: {
          lat: 43.0741904,
          lng: -89.3809802
        }
      })
      .then(marker => {
        marker.on(GoogleMapsEvent.MARKER_CLICK)
          .subscribe(() => {
              
          });
      });
    })
    .catch(error =>{
     
    });

  }

  getPosition(): void{
    this.map.getMyLocation()
    .then(response => {
      this.map.moveCamera({
        target: response.latLng
      });
      this.map.addMarker({
        title: 'My Position',
        icon: 'blue',
        animation: 'DROP',
        position: response.latLng
      });
    })
    .catch(error =>{
    
    });
  }


}
