import { Injectable }                                        from '@angular/core';
import { Http, Headers }                                     from '@angular/http';
import { RequestMethod, RequestOptions, RequestOptionsArgs } from '@angular/http';
import { Response }                                          from '@angular/http';
import { Storage }                                           from '@ionic/storage';

import { Observable }                                        from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import "rxjs/add/operator/do";
import "rxjs/add/operator/catch";


import { Platform } from 'ionic-angular';
import { Device } from '@ionic-native/device';
import { LocalStorageProvider } from '../../providers/local-storage/local-storage';

@Injectable()
export class LoginServiceProvider {

  private KEY_TOKEN = 'token_jwt';
  private jwtToken = null;
  protected basePath = 'https://api.quedadas.ovh';
  private pushToken = null;
  private KEY_TOKEN_PUSH = 'token_push';
  platformDevice: string;
  public uuid: string;
  model: string;

  constructor(public http: Http, public storage: Storage, public plt: Platform, private device: Device, private localStorageProvider: LocalStorageProvider) {
    
    this.getToken()
      .then(
        () => console.log('Current token', this.jwtToken),
        () => console.log('No current token', this.jwtToken)
      );
  }

    // Manage token in local storage
    private getToken() {
      return this.storage.get(this.KEY_TOKEN)
        .then((value) => this.jwtToken = value)
        .catch(() => this.jwtToken = null);
    }
  
    private setToken(token: string) {
      this.jwtToken = token;
      this.storage.set(this.KEY_TOKEN, token);
    }

  doLogout() {
    this.jwtToken = null;
    this.storage.remove(this.KEY_TOKEN);
  }
    
  checkLogin(){
    return !!this.jwtToken;
  }

  createHeaders(jwt: string): Headers {
    // Set headers for request
    let headers = new Headers();
    headers.append('Content-Type', 'application/json');
    headers.append('Accept', 'application/json');

    // Add jwt if declared
    if(!!jwt) {
      headers.append('Authorization', 'Bearer ' + jwt);
    }

    return headers;
  }

  doLogin(providerytoken: any){
    return new Promise((resolve, reject)=>{
      this.http.post(this.basePath, providerytoken)
        .map(res=> res.json())
        .subscribe(data=>{
          resolve(data);
        }, error=>{
          reject(error);
        })
    });
      
  }

  public doSocial(provider: string, token: string, secret: string): Observable<Object> {
    // Url to social login
    const path = this.basePath + '/auth/social';
    // Set headers without jwt
    const headers = this.createHeaders(null);
    // Set body
    const body = JSON.stringify({
      provider,
      access_token: token,
      token_secret: secret // only twitter, but others provider ignoring it
    });

    let requestOptions: RequestOptionsArgs = new RequestOptions({
        method: RequestMethod.Post,
        headers: headers,
        body
    });

    return this.http.request(path, requestOptions)
      .map((response: Response) => response.json())
      .do((data) => this.handleLogin(data))
      .catch((error) => this.handleErrors(error));
  }

  handleLogin(data: any) {
   	if( data.code == undefined) {
      
      this.setToken(data.token);
      // TODO: Extact user info from jwt and return
      return data.token;
    }
    else {
   
			return Observable.throw(data.code);
		}
	}

	handleErrors(error: Response | any) {
	  let errMsg: string;
	  if (error instanceof Response) {
	    errMsg = error.status + '';
    }
    else {
      // Manage 401? thow others?... or 400 for default error?
	    errMsg = error.message ? error.message : '400';
	  }
	  return Observable.throw(errMsg);
  }

  private getTokenPush() {
    return this.storage.get(this.KEY_TOKEN_PUSH)
      .then((value) => this.pushToken = value)
      .catch(() => this.pushToken = null);
  }
  
  

  registerDevice(tokenPush: string){
    return this.getToken()
    .then(
      () => {console.log('Current token con jwt', this.jwtToken)
      let headers = new Headers();
      headers.append('Content-Type', 'application/json');
      headers.append('Authorization', 'Bearer ' + this.jwtToken);
      
      if(this.plt.is('android'))
      {
        this.platformDevice = 'android'
      }

      this.model = this.device.model;

      const body = JSON.stringify({
        deviceId: this.device.uuid,
        registerToken: tokenPush,
        model: this.model,
        platform: this.platformDevice
      });

     

      const path = this.basePath + '/register/device';
      return new Promise((resolve, reject)=>{
        this.http.post(path, body, {headers: headers})
        .map(res=> res.json())
        .subscribe(data=>{
        
          resolve(data)
         
        }, error =>{
          reject(error);
        })
      });
      },
      () => console.log('Current token', this.jwtToken)
    );
}

}
