import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { QuedadaModel } from '../../models/quedada-model';
import 'rxjs/add/operator/map';
import { Http, Headers } from '@angular/http'
import { Storage } from '@ionic/storage';

@Injectable()
export class QuedadasApiProvider {

  path: string = 'https://api.quedadas.ovh';
  private KEY_TOKEN = 'token_jwt';
  public jwtToken = null;
  jwt: string = '';

  constructor(public http: Http, public storage: Storage) {
   
  }

  
  getQuedadas(token: string){
    let headers = new Headers();
    headers.append('Content-Type', 'application/json');
    headers.append('Authorization', 'Bearer ' + token);

    return new Promise((resolve, reject)=>{
      this.http.get(`${this.path}/meetings?pageSize=99`, {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }


  getQuedada(token: string, id: string){
    let headers = new Headers();
    headers.append('Content-Type', 'application/json');
    headers.append('Authorization', 'Bearer ' + token);

    return new Promise((resolve, reject)=>{
      this.http.get(`${this.path}/meetings/`+id, {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }

  joinQuedada(token: string, id: string){
    let headers = new Headers();
       headers.append('Authorization', 'Bearer ' + token);
       headers.append('Content-Type', 'application/json');
    
    return new Promise((resolve, reject)=>{
      this.http.post(`${this.path}/meetings/`+id+'/join', '', {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }

  attendQuedada(token: string, id: string){
    let headers = new Headers();
       headers.append('Authorization', 'Bearer ' + token);
       headers.append('Content-Type', 'application/json');
  
    
    return new Promise((resolve, reject)=>{
      this.http.post(`${this.path}/meetings/`+id+'/attend/yes', '', {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }


  doNotAttendQuedada(token: string, id: string){
    let headers = new Headers();
       headers.append('Authorization', 'Bearer ' + token);
       headers.append('Content-Type', 'application/json');
  
    
    return new Promise((resolve, reject)=>{
      this.http.post(`${this.path}/meetings/`+id+'/attend/no', '', {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }

  maybeAttendQuedada(token: string, id: string){
    let headers = new Headers();
       headers.append('Authorization', 'Bearer ' + token);
       headers.append('Content-Type', 'application/json');
  
    
    return new Promise((resolve, reject)=>{
      this.http.post(`${this.path}/meetings/`+id+'/attend/maybe', '', {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }

  cancelQuedada(token: string, id: string){
    let headers = new Headers();
       headers.append('Authorization', 'Bearer ' + token);
       headers.append('Content-Type', 'application/json');
  
    
    return new Promise((resolve, reject)=>{
      this.http.post(`${this.path}/meetings/`+id+'/cancel', '', {headers: headers})
      .map(res=> res.json())
      .subscribe(data=>{
        resolve(data)
      }, error =>{
        reject(error);
      })
    });
  }

  createQuedada(quedada: any){
  
    return this.getToken()
    .then(
      () => {
      let headers = new Headers();
      headers.append('Content-Type', 'application/json');
      headers.append('Authorization', 'Bearer ' + this.jwtToken);
      
      return new Promise((resolve, reject)=>{
        this.http.post(`${this.path}/meetings`, quedada, {headers: headers})
        .map(res=> res.json())
        .subscribe(data=>{
          resolve(data)
        }, error =>{
          reject(error);
        })
      });},
      () => console.log('Current token', this.jwtToken)
    );

  }

  editQuedada(quedada: any, id: string){
    return this.getToken()
    .then(
      () => {
      let headers = new Headers();
      headers.append('Content-Type', 'application/json');
      headers.append('Authorization', 'Bearer ' + this.jwtToken);
     
      return new Promise((resolve, reject)=>{
        this.http.put(`${this.path}/meetings/`+id, quedada, {headers: headers})
        .map(res=> res.json())
        .subscribe(data=>{
          resolve(data)
        }, error =>{
          reject(error);
        })
      });},
      () => console.log('Current token', this.jwtToken)
    );
  }

 


  private getToken() {
    return this.storage.get(this.KEY_TOKEN)
      .then((value) => this.jwtToken = value)
      .catch(() => this.jwtToken = null);
  }

}
